@@ -1,28 +1,24 @@
-   /****************************************************************
+/************************************************************************
     Copyright (C) 1986-2000 by
 
     F6FBB - Jean-Paul ROUBELAT
-    6, rue George Sand
-    31120 - Roquettes - France
-	jpr@f6fbb.org
+    jpr@f6fbb.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
     Parts of code have been taken from many other softwares.
     Thanks for the help.
-    ****************************************************************/
+************************************************************************/
 
 /*
  *   Gestion de la console
@@ -1000,7 +996,7 @@ void free_mem (void)
 			mem[meminfo_main][meminfo_free] +
 			mem[meminfo_main][meminfo_buffers] +
 			mem[meminfo_total][meminfo_cached] +
-			mem[meminfo_swap][meminfo_free];
+			mem[meminfo_swap][meminfo_free];	
 	}
 
 	FbbMem (0);
@@ -1154,7 +1150,6 @@ char *yapp_str (int voie, char *s)
 	{"Yapp", "YapC"};
 	Svoie *pv = svoie[voie];
 	int i;
-	int ok = 1;
 	int retour = 0;
 	int niv = pv->niv2;
 	long offset = pv->enrcur;
@@ -1208,9 +1203,7 @@ char *yapp_str (int voie, char *s)
 			}
 		}
 	}
-	else
-		ok = 0;
-
+	
 	return (s);
 }
 
@@ -1327,12 +1320,12 @@ int ind_console (int type, char *chaine)	/* Type : 0 = decimal, 1 = hexa */
 
 void house_keeping (void)
 {
-	long caltemps;
+	//long caltemps;
 
 	save_fic = 1;
 	set_busy ();
-	time (&caltemps);
-	stop_min = minute (caltemps);
+	//time (&caltemps);
+	//stop_min = minute (caltemps);
 	type_sortie = 3;
 }
 
