@@ -1,28 +1,24 @@
-   /****************************************************************
+/************************************************************************
     Copyright (C) 1986-2000 by
 
     F6FBB - Jean-Paul ROUBELAT
-    6, rue George Sand
-    31120 - Roquettes - France
-	jpr@f6fbb.org
+    jpr@f6fbb.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
     Parts of code have been taken from many other softwares.
     Thanks for the help.
-    ****************************************************************/
+************************************************************************/
 
 
  /******************************************************
@@ -186,13 +182,11 @@ int snd_sck (int port, int canal, int cmd, char *buffer, int len, Beacon * ptr)
 		break;
 
 	case DATA:
-		if (len == 0) {
-/*			fprintf (stderr, "FBB snd_sck() DATA len == 0 !\n");*/
-			break;
-		}
-		else
+		if (len != 0)
 			ret = sock_snd_dt (canal, buffer, len);
-			break;
+		//else
+			//fprintf (stderr, "FBB snd_sck() DATA len == 0 !\n");			
+		break;		
 
 	case UNPROTO:
 		ret = sock_snd_ui (port, buffer, len, ptr);
@@ -205,12 +199,12 @@ int snd_sck (int port, int canal, int cmd, char *buffer, int len, Beacon * ptr)
 int rcv_sck (int *port, int *canal, int *cmd, char *buffer, int *len, ui_header * ui)
 {
 	static int can = 0;
-	int valid;
+/*	int valid;*/
 	int res;
 
 	*cmd = INVCMD;
 
-	valid = 0;
+/*	valid = 0;*/
 
 	/* Test monitoring */
 
@@ -234,7 +228,10 @@ int rcv_sck (int *port, int *canal, int *cmd, char *buffer, int *len, ui_header
 		unsigned addr_len;
 		union sockaddr_ham addr;
 
-		addr_len = sizeof (union sockaddr_ham);
+		memset(&addr, 0x00, sizeof(struct full_sockaddr_ax25));
+
+/*		addr_len = sizeof (union sockaddr_ham);*/
+		addr_len = sizeof (struct full_sockaddr_ax25);
 
 		new = accept (p_port[*port].fd, (struct sockaddr *) &addr, &addr_len);
 		if (new == -1)
@@ -317,7 +314,10 @@ int rcv_sck (int *port, int *canal, int *cmd, char *buffer, int *len, ui_header
 			union sockaddr_ham addr;
 			int ret;
 
-			addr_len = sizeof (union sockaddr_ham);
+			memset(&addr, 0x00, sizeof(struct full_sockaddr_ax25));
+			
+/*			addr_len = sizeof (union sockaddr_ham);*/
+			addr_len = sizeof (struct full_sockaddr_ax25);
 
 			if (getpeername (scan[can].sock, (struct sockaddr *) &addr, &addr_len) == 0)
 			{
@@ -480,6 +480,8 @@ int opn_sck (int port, int nb)
 		char call[20];
 		int addrlen = 0;
 		union sockaddr_ham addr;
+		
+		memset(&addr, 0x00, sizeof(struct full_sockaddr_ax25));
 
 		sprintf (s, "Open PORT %d COM%d-%d",
 				 port, p_port[port].ccom, p_port[port].ccanal);
@@ -534,7 +536,7 @@ int opn_sck (int port, int nb)
 			addr.axaddr.fsa_ax25.sax25_ndigis = 1;
 			sprintf (call, "%s-%d", mycall, myssid);
 
-			fprintf (stderr, "CAN_AX25 myscall %s myssid %d\n", mycall, myssid);
+			fprintf (stderr, "CAN_AX25 mycall %s myssid %d\n", mycall, myssid);
 
 			ax25_aton_entry (call, addr.axaddr.fsa_ax25.sax25_call.ax25_call);
 			p_name = ax25_config_get_addr (p_port[port].name);
@@ -716,9 +718,15 @@ static int sock_rcv_ui (int *port, char *buffer, int *plen, ui_header * phead)
 	char *pctl;
 	int b_port;
 	int family;
-	int prevp;
+/*	int prevp;*/
 	char name[80];
 	
+	memset(&sa, 0x00, sizeof(struct sockaddr));
+	memset(&ifr, 0x00, sizeof(struct ifreq));
+	memset(buf, 0, sizeof(buf));
+	memset(temp, 0, sizeof(temp));
+	memset(name, 0, sizeof(name));
+
 	do
 	{
 		b_port = *port;
@@ -905,7 +913,7 @@ static int sock_rcv_ui (int *port, char *buffer, int *plen, ui_header * phead)
 	else
 		phead->pid = 0;
 
-	prevp = b_port;
+/*	prevp = b_port;*/
 	if (b_port == 0)
 	{
 		int bp;
@@ -961,6 +969,9 @@ static int sock_snd_ui (int port, char *chaine, int len, Beacon * beacon)
 	int i;
 	int nb;
 	int s;
+	
+	memset(&src, 0x00, sizeof(struct full_sockaddr_ax25));
+	memset(&dest, 0x00, sizeof(struct full_sockaddr_ax25));
 
 	nb = 0;
 	calls[nb] = malloc (AX25_CALLSID);
@@ -1036,8 +1047,13 @@ static int sock_snd_dt (int canal, char *buffer, int len)
 }
 
 static int sock_cmd (int port, int canal, char *cmd)
-{
-	strcpy (scan[canal].source, "\0") ;
+{	
+	/* Dave van der Locht 27-01-2020
+	Why clearing scan[canal].source? The second call to this function, after the I command, 
+	forces the gateway to use the BBS's own callsign as FROM address.
+	*/
+	
+	//strcpy (scan[canal].source, "\0") ;
 
 	switch (*cmd++)
 	{
@@ -1064,7 +1080,7 @@ static int sock_cmd (int port, int canal, char *cmd)
 		scan[canal].paclen = p_port[port].pk_t;
 		scan[canal].maxframe = p_port[port].frame;
 		scan[canal].port = port;
-		scan[canal].type = p_port[port].type;
+		scan[canal].type = p_port[port].type;	
 
 		sock_connect (cmd, canal);
 		break;
@@ -1073,12 +1089,15 @@ static int sock_cmd (int port, int canal, char *cmd)
 	}
 	return (1);
 }
+
 static int nr_ax25_aton (char *address, struct full_sockaddr_ax25 *addr)
 {
 	char buffer[100], *call, *alias;
 	FILE *fp;
 	int addrlen;
 
+	memset(buffer, 0, sizeof(buffer));
+
 	call = address;
 
 	while (*call)
@@ -1118,6 +1137,7 @@ static int nr_ax25_aton (char *address, struct full_sockaddr_ax25 *addr)
 
 	return -1;
 }
+
 static int rs_ax25_aton (char *address, struct sockaddr_rose *addr)
 {
 	char *command, *call, *rsaddr, *digi;
@@ -1206,6 +1226,9 @@ static int sock_connect (char *commande, int can)
 	char mycallsign[AX25_CALLSID];
 	int backoff = 0;
 
+	memset(&addr, 0x00, sizeof(struct full_sockaddr_ax25));
+	memset(mycallsign, 0, sizeof(mycallsign));
+
 	if (strcmp(scan[can].source,"") != 0 )
 	{
 		strcpy (mycallsign, scan[can].source);
@@ -1430,6 +1453,8 @@ static int sock_stat (int canal, stat_ch * ptr)
  */
  	struct ax25_info_struct ax25info; 
  
+	memset(&ax25info, 0x00, sizeof(struct ax25_info_struct));
+
 /*	struct ax25_info_struct_new ax25info;
 */
 	if (scan[canal].sock <= 0)
@@ -1631,6 +1656,8 @@ static int sock_connexion (int new, int can, union sockaddr_ham *addr, int *port
 	char Dnic[80];
 	union sockaddr_ham addrham;
 
+	memset(&addrham, 0x00, sizeof(struct full_sockaddr_ax25));
+	
 	scan[can].state = CONNECTED;
 	scan[can].sock = new;
 
