@@ -1,28 +1,24 @@
-   /****************************************************************
+/************************************************************************
     Copyright (C) 1986-2000 by
 
     F6FBB - Jean-Paul ROUBELAT
-    6, rue George Sand
-    31120 - Roquettes - France
-	jpr@f6fbb.org
+    jpr@f6fbb.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
     Parts of code have been taken from many other softwares.
     Thanks for the help.
-    ****************************************************************/
+************************************************************************/
 
 #include <serv.h>
 
@@ -131,17 +127,25 @@ void initport (void)
 		if ((fptr = fopen (c_disque ("port.sys"), "r")) == NULL)
 		{
 #ifdef ENGLISH
-			errport (lig, "File PORT.SYS not found    ");
+			errport (lig, "File PORT.SYS not found");
 #else
 			errport (lig, "Fichier PORT.SYS inexistant");
 #endif
 			return;
 		}
 	}
+#ifdef __linux__
+#ifdef ENGLISH
+	cprintf ("Ports set-up            \n");
+#else
+	cprintf ("Initialisation des ports\n");
+#endif
+#else
 #ifdef ENGLISH
 	cprintf ("Ports set-up            \r\n");
 #else
 	cprintf ("Initialisation des ports\r\n");
+#endif
 #endif
 
 	al = sizeof (defport) * NBPORT;
@@ -916,10 +920,18 @@ void initport (void)
 	{
 		svoie[voie]->paclen = p_port[no_port (voie)].pk_t;
 	}
+#ifdef __linux__
+#ifdef ENGLISH
+	cprintf ("%d channels ok  \n", nbvalid);
+#else
+	cprintf ("%d voies valides\n", nbvalid);
+#endif
+#else
 #ifdef ENGLISH
 	cprintf ("%d channels ok  \r\n", nbvalid);
 #else
 	cprintf ("%d voies valides\r\n", nbvalid);
+#endif
 #endif
 
 	MWARNING = NBVOIES;
@@ -1015,12 +1027,22 @@ void initexte (void)
 		return;
 	}
 
+#ifdef __linux__
+#ifdef ENGLISH
+	cprintf ("Texts set-up             \n");
+
+#else
+	cprintf ("Initialisation des textes\n");
+
+#endif
+#else
 #ifdef ENGLISH
 	cprintf ("Texts set-up             \r\n");
 
 #else
 	cprintf ("Initialisation des textes\r\n");
 
+#endif
 #endif
 	nbc = cpt = 0;
 #ifdef ENGLISH
@@ -1075,10 +1097,18 @@ void initexte (void)
 #endif
 			++niv;
 			nomlang = (char *) m_alloue (LG_LANG * nbc);
+#ifdef __linux__
+#ifdef ENGLISH
+			cprintf ("%d language buffers allocated\n", NBLANG);
+#else
+			cprintf ("%d buffers langue allous    \n", NBLANG);
+#endif
+#else
 #ifdef ENGLISH
 			cprintf ("%d language buffers allocated\r\n", NBLANG);
 #else
 			cprintf ("%d buffers langue allous    \r\n", NBLANG);
+#endif
 #endif
 			break;
 		case 1:
