@@ -1,28 +1,24 @@
-   /****************************************************************
+/************************************************************************
     Copyright (C) 1986-2000 by
 
     F6FBB - Jean-Paul ROUBELAT
-    6, rue George Sand
-    31120 - Roquettes - France
-	jpr@f6fbb.org
+    jpr@f6fbb.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
     Parts of code have been taken from many other softwares.
     Thanks for the help.
-    ****************************************************************/
+************************************************************************/
 
 /*
  * TRAIT.C
@@ -303,14 +299,16 @@ static void arret_serveur (char *fich_etat, int typ)
 		house_keeping ();
 		break;
 
-	case 'L':	/* Re-Run */
+	case 'L':	/* Re-Run, wait till all users have disconnected */		
 		texte (T_TRT + 9);
 		save_fic = 1;
 #ifdef __FBBDOS__
 		affich_logo (W_DEFL);
-#endif
-		type_sortie = 2;
+#endif        
+	    time (&caltemps);
+	    stop_min = minute (caltemps);
 		set_busy ();
+		type_sortie = 2;		
 		break;
 
 	case 'M':	/* Immediate Re-run */
@@ -745,14 +743,20 @@ void finentete (void)
 	char s[80];
 	struct stat bufstat;
 
+	memset(&bufstat, 0x00, sizeof(struct stat));
+
 	sprintf (s, "LANG\\%s.ENT", nomlang + nlang * LG_LANG);
 	outfich (c_disque (s));
+/*	fprintf (stderr, "%s\n", c_disque(s));*/
+
 	sprintf (s, "LANG\\%s.NEW", nomlang + nlang * LG_LANG);
 	if ((stat (c_disque (s), &bufstat) == 0) && (bufstat.st_ctime != pvoie->finf.newbanner))
 	{
 		pvoie->finf.newbanner = bufstat.st_ctime;
 		outfich (c_disque (s));
 	}
+/*	fprintf (stderr, "%s\n", c_disque(s));*/
+
 	if ((pvoie->ncur->nbmess) && (strcmp (pvoie->ncur->indic, "MODEM") != 0))
 	{
 		if (pvoie->ncur->nbnew)
